@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2021-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2021-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -53,14 +53,15 @@ MailMergeConfigureDialog::MailMergeConfigureDialog(QWidget *parent)
                                       QStringLiteral(KDEPIM_VERSION),
                                       i18n("Merge email addresses agent."),
                                       KAboutLicense::GPL_V2,
-                                      i18n("Copyright (C) 2021-%1 Laurent Montel", QStringLiteral("2024")));
+                                      i18n("Copyright (C) 2021-%1 Laurent Montel", QStringLiteral("2025")));
 
     aboutData.addAuthor(i18nc("@info:credit", "Laurent Montel"), i18n("Maintainer"), QStringLiteral("montel@kde.org"));
     aboutData.setProductName(QByteArrayLiteral("Akonadi/MailMergeAgent"));
     QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("kmail")));
     aboutData.setTranslator(i18nc("NAME OF TRANSLATORS", "Your names"), i18nc("EMAIL OF TRANSLATORS", "Your emails"));
 
-    auto helpMenu = new KHelpMenu(this, aboutData, true);
+    auto helpMenu = new KHelpMenu(this, aboutData);
+    helpMenu->setShowWhatsThis(true);
     // Initialize menu
     QMenu *menu = helpMenu->menu();
     helpMenu->action(KHelpMenu::menuAboutApp)->setIcon(QIcon::fromTheme(QStringLiteral("kmail")));
