@@ -1,11 +1,12 @@
 /*
-  SPDX-FileCopyrightText: 2013-2024 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2025 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
 #pragma once
 
+#include "config-kmail.h"
 #include "configuredialog_p.h"
 #include "kmail_export.h"
 #include "ui_miscpagemaintab.h"
@@ -77,7 +78,7 @@ private:
     MessageViewer::PrintingSettings *const mPrintingUi;
 };
 
-#ifdef WITH_KUSERFEEDBACK
+#if KMAIL_WITH_KUSERFEEDBACK
 namespace KUserFeedback
 {
 class FeedbackConfigWidget;
