@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2024 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2025 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -237,7 +237,11 @@ SecurityPageEncryptionTab::SecurityPageEncryptionTab(QWidget *parent)
     connect(mWidget->mWarnEncrChainCertExpiresSB, &QSpinBox::valueChanged, this, &SecurityPageEncryptionTab::slotEmitChanged);
     connect(mWidget->mWarnEncrRootCertExpiresSB, &QSpinBox::valueChanged, this, &SecurityPageEncryptionTab::slotEmitChanged);
 
+#ifndef Q_OS_WIN
     connect(mWidget->gnupgButton, &QPushButton::clicked, this, &SecurityPageEncryptionTab::slotConfigureGnupg);
+#else
+    mWidget->gnupgButton->hide();
+#endif
     connect(mWidget->enableAllWarningsPB, &QPushButton::clicked, this, &SecurityPageEncryptionTab::slotReenableAllWarningsClicked);
 }
 
@@ -315,7 +319,7 @@ void SecurityPageEncryptionTab::slotConfigureGnupg()
     QPointer<GpgSettingsDialog> dlg(new GpgSettingsDialog(this));
     dlg->setWindowTitle(i18nc("@title:window", "GnuPG Settings"));
     KPageWidgetItem *page = nullptr;
-    const auto plugin = KPluginMetaData::findPluginById((QStringLiteral("pim6/kcms/kleopatra")), QStringLiteral("kleopatra_config_gnupgsystem"));
+    const auto plugin = KPluginMetaData::findPluginById((QStringLiteral("pim6/kcms/kleopatra")), QStringLiteral("kcm_kmail_gnupgsystem"));
     if (plugin.isValid()) {
         page = dlg->addModule(plugin);
     }
@@ -476,7 +480,7 @@ struct SMIMECryptoConfigEntries {
     QGpgME::CryptoConfigEntry *mCustomHTTPProxy = nullptr;
     QGpgME::CryptoConfigEntry *mCustomLDAPProxy = nullptr;
 
-    QGpgME::CryptoConfig *mConfig = nullptr;
+    QGpgME::CryptoConfig *const mConfig;
 };
 
 void SecurityPageSMimeTab::doLoadOther()
