@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -8,7 +8,7 @@
 using namespace Qt::Literals::StringLiterals;
 
 #include "kmkernel.h"
-#include <MessageComposer/Composer>
+#include <MessageComposer/ComposerJob>
 #include <MessageViewer/MessageViewerSettings>
 
 #include <MessageComposer/MessageHelper>
@@ -57,7 +57,7 @@ void FillComposerJob::start()
 
 void FillComposerJob::slotOpenComposer()
 {
-    KMail::Composer::TemplateContext context = KMail::Composer::New;
+    KMail::Composer::TemplateContext context = KMail::Composer::TemplateContext::New;
     KMime::Content *msgPart = nullptr;
     bool iCalAutoSend = false;
     bool noWordWrap = false;
@@ -105,7 +105,7 @@ void FillComposerJob::slotOpenComposer()
     mMsg->assemble();
 
     if (!mMsg->body().isEmpty()) {
-        context = KMail::Composer::NoTemplate;
+        context = KMail::Composer::TemplateContext::NoTemplate;
     }
 
     KMail::Composer *cWin = KMail::makeComposer(KMime::Message::Ptr(), false, false, context);
